### Astra Python SDK

Detailed documentation available at https://docs.astra.finance.

## Getting Started

# Installation

`pip install astra-python`

```
from astra import Astra

astra_client = Astra(MY_CLIENT_ID, MY_CLIENT_SECRET)
astra_client.create_routine(routine_data, user_access_token)
```
